@@ -5,8 +5,8 @@ from ..options.britive_options import britive_options
 
 @click.command()
 @build_britive
-@britive_options(names='tenant,token,passphrase')
-def login(ctx, tenant, token, passphrase):
+@britive_options(names='tenant,token,passphrase,federation_provider')
+def login(ctx, tenant, token, passphrase, federation_provider):
     """Perform an interactive login to obtain temporary credentials.
 
     This only applies when an API token has not been specified via `--token,-T` or via environment variable
