@@ -1,4 +1,5 @@
 import os
+import shutil
 from pathlib import Path
 import click
 import configparser
@@ -65,6 +66,10 @@ class ConfigManager:
         self.loaded = False
         self.validation_error_messages = []
 
+    def clear_gcloud_auth_key_files(self):
+        path = Path(self.path).parent / 'pybritive-gcloud-key-files'
+        shutil.rmtree(str(path), ignore_errors=True)
+
     def get_output_format(self, output_format: str = None):
         return coalesce(
             output_format,
